@@ -1,10 +1,10 @@
 # © Copyright 2022 CERN. This software is distributed under the terms of
 # the GNU General Public Licence version 3 (GPL Version 3), copied verbatim
-# in the file "LICENCE.txt". In applying this licence, CERN does not waive
+# in the file 'LICENCE.txt'. In applying this licence, CERN does not waive
 # the privileges and immunities granted to it by virtue of its status as an
 # Intergovernmental Organization or submit itself to any jurisdiction.
 
-__docformat__ = "google"
+__docformat__ = 'google'
 
 import os
 import ssl
@@ -179,11 +179,10 @@ def send_email(params, message):
     data_gigabytes, throughput_gigabits, parallel_transfers, queued_transfers, timestamp = get_metrics_link(df_last_event)
     # Write content of the email into a txt file
     with open(''.join([os.getcwd(), '/noted/logs/noted_email.txt']), 'w') as f:
-        f.write('From: noted@cern.ch\n')
-        f.write('To: ' + str(class_transfer_broker_.get_list_email_address()) + '\n')
-        f.write('Subject: [NOTED] Notification\n\n')
-        f.write('Hi,\n\n')
-        f.write('New transfer detected...\n\n')
+        f.write('From: ' + class_transfer_broker_.get_from_email_address() + '\n')
+        f.write('To: '   + class_transfer_broker_.get_to_email_address()   + '\n')
+        f.write('Subject: ' + class_transfer_broker_.get_subject_email()   + '\n')
+        f.write(class_transfer_broker_.get_message_email() + '\n')
         f.write(message + '\n\n')
         if 'src_rcsite' in threading.current_thread().name:
             f.write('LHCOPN Source: '      + str(class_transfer_broker_.get_list_src_rcsites()) + '\n')
@@ -196,8 +195,6 @@ def send_email(params, message):
         f.write('\tQueued transfers: '     + str(queued_transfers)     + '\n')
         f.write('\tThroughput [Gb/s]: '    + str(throughput_gigabits)  + '\n')
         f.write('\tAmount of data [GB]: '  + str(data_gigabytes)       + '\n\n')
-        f.write('Cheers,\n')
-        f.write('NOTED\n')
     # Send email
     cmd = os.popen('sendmail -vt < ' + ''.join([os.getcwd(), '/noted/logs/noted_email.txt']))
     return
@@ -303,12 +300,12 @@ def sense_dynamic_circuit(params, task, action, message):
     logging.warning('Calling to sense-o API to %s a dynamic circuit.' % task)
     # Provision dynamic circuit with sense-o
     if 'provision' in task:
-        cmd = os.popen(str('sh sense-o/sense-provision.sh ' + class_transfer_broker_.get_sense_uuid() + ' ' + class_transfer_broker_.get_sense_vlan()));
-        cmd = os.popen(str('sh sense-o/sense-provision.sh ' + class_transfer_broker_.get_sense_uuid_2() + ' ' + class_transfer_broker_.get_sense_vlan_2()));
+        cmd = os.popen(str('sh noted/sense-o/sense-provision.sh ' + class_transfer_broker_.get_sense_uuid()   + ' ' + class_transfer_broker_.get_sense_vlan()));
+        cmd = os.popen(str('sh noted/sense-o/sense-provision.sh ' + class_transfer_broker_.get_sense_uuid_2() + ' ' + class_transfer_broker_.get_sense_vlan_2()));
     # Cancel dynamic circuit with sense-o
     else:
-        cmd = os.popen(str('sh sense-o/sense-cancel.sh ' + class_transfer_broker_.get_sense_uuid() + ' ' + class_transfer_broker_.get_sense_vlan()));
-        cmd = os.popen(str('sh sense-o/sense-cancel.sh ' + class_transfer_broker_.get_sense_uuid_2() + ' ' + class_transfer_broker_.get_sense_vlan_2()));
+        cmd = os.popen(str('sh noted/sense-o/sense-cancel.sh ' + class_transfer_broker_.get_sense_uuid()   + ' ' + class_transfer_broker_.get_sense_vlan()));
+        cmd = os.popen(str('sh noted/sense-o/sense-cancel.sh ' + class_transfer_broker_.get_sense_uuid_2() + ' ' + class_transfer_broker_.get_sense_vlan_2()));
     send_email(params, message)
     if 'src_rcsite' in threading.current_thread().name: filename = params.get('FILENAME PARAMETERS', 'filename_transfers_src')
     else: filename = params.get('FILENAME PARAMETERS', 'filename_transfers_dst')
@@ -537,9 +534,6 @@ def start_threads(transfers_tx, transfers_rx):
 def main():
 
     """Main function."""
-    # Logging
-    logging.basicConfig(level = logging.NOTSET, filename = ''.join([os.getcwd(), '/noted/logs/transfer_broker_' + app_timestamp + '.log']), filemode = 'w', format = '%(asctime)s %(name)s - %(levelname)s - %(threadName)s: %(message)s')
-    logging.getLogger('numexpr.utils').setLevel(logging.WARNING) # hide logging messages from numexpr.utils module
     # Config parser
     params = configparser.ConfigParser(interpolation = configparser.ExtendedInterpolation())
     params.read(''.join([get_python_lib(), '/noted/params/params.ini']))
@@ -548,6 +542,9 @@ def main():
     args_parser.add_argument('config_file', help = 'the name of the configuration file [config-example.yaml]')
     args_parser.add_argument('-v', '--verbosity', help = 'defines the logging level [debug, info, warning]')
     args = args_parser.parse_args()
+    # Logging
+    logging.basicConfig(level = logging.NOTSET, filename = ''.join([os.getcwd(), '/noted/logs/transfer_broker_' + app_timestamp + '.log']), filemode = 'w', format = '%(asctime)s %(name)s - %(levelname)s - %(threadName)s: %(message)s')
+    logging.getLogger('numexpr.utils').setLevel(logging.WARNING) # hide logging messages from numexpr.utils module
     # Set verbosity level
     if args.verbosity is not None:
         if   'debug'   in args.verbosity: logging.getLogger().setLevel(logging.DEBUG)
@@ -559,14 +556,17 @@ def main():
     logging.info('Source rcsite: %s' % config['src_rcsite'])
     logging.info('Destination rcsite: %s' % config['dst_rcsite'])
     # CRIC database
-    df_cric_database = query_cric_database(params)
+    df_cric_database   = query_cric_database(params)
     # Generate queries
     list_src_endpoints = generate_query(config, params, 'src_rcsite', df_cric_database)
     list_dst_endpoints = generate_query(config, params, 'dst_rcsite', df_cric_database)
     # Set the attributes of the class transfer broker
     class_transfer_broker_.set_list_src_rcsites(config['src_rcsite'])
     class_transfer_broker_.set_list_dst_rcsites(config['dst_rcsite'])
-    class_transfer_broker_.set_list_email_address(config['email_address'])
+    class_transfer_broker_.set_from_email_address(config['from_email_address'])
+    class_transfer_broker_.set_to_email_address(config['to_email_address'])
+    class_transfer_broker_.set_subject_email(config['subject_email'])
+    class_transfer_broker_.set_message_email(config['message_email'])
     class_transfer_broker_.set_list_src_endpoints(list_src_endpoints)
     class_transfer_broker_.set_list_dst_endpoints(list_dst_endpoints)
     class_transfer_broker_.set_unidirectional(config['unidirectional_link'])
